# Google AI Studio

A collection of AI tools built on Google Vertex AI APIs.

Current available features:

* a simple chat bot built on Google Gemini Pro

plan: vision and other features

It is part of integrated tools, developed in our [LetMeDoIt AI project](https://github.com/eliranwong/letmedoit).

# Install

> pip install --upgrade googleaistudio

# Google API Setup

Save a copy of your API key JSON file as "~/credentials_googleaistudio.json", where "~" denotes your home directory.

Read https://github.com/eliranwong/letmedoit/wiki/Google-API-Setup for setting up Google API.

# Usage

> geminipro
